==> keycloak-model-map-17.0.1-sources.jar: org/keycloak/models/map/user/MapUserCredentialEntityDelegate.java <==
package org.keycloak.models.map.user;
public class MapUserCredentialEntityDelegate implements org.keycloak.models.map.user.MapUserCredentialEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserCredentialEntity> delegateProvider;
    public MapUserCredentialEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserCredentialEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserCredentialEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserCredentialEntityFields.ID, id).setId(id);
    }
    @Override public String getType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserCredentialEntityFields.TYPE).getType();
    }
    @Override public void setType(String type) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserCredentialEntityFields.TYPE, type).setType(type);
    }
    @Override public String getUserLabel() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserCredentialEntityFields.USER_LABEL).getUserLabel();
    }
    @Override public void setUserLabel(String userLabel) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserCredentialEntityFields.USER_LABEL, userLabel).setUserLabel(userLabel);
    }
    @Override public Long getCreatedDate() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserCredentialEntityFields.CREATED_DATE).getCreatedDate();
    }
    @Override public void setCreatedDate(Long createdDate) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserCredentialEntityFields.CREATED_DATE, createdDate).setCreatedDate(createdDate);
    }
    @Override public String getSecretData() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserCredentialEntityFields.SECRET_DATA).getSecretData();
    }
    @Override public void setSecretData(String secretData) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserCredentialEntityFields.SECRET_DATA, secretData).setSecretData(secretData);
    }
    @Override public String getCredentialData() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserCredentialEntityFields.CREDENTIAL_DATA).getCredentialData();
    }
    @Override public void setCredentialData(String credentialData) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserCredentialEntityFields.CREDENTIAL_DATA, credentialData).setCredentialData(credentialData);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/user/MapUserCredentialEntityDelegate.java <==
package org.keycloak.models.map.user;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapUserCredentialEntityDelegate implements org.keycloak.models.map.user.MapUserCredentialEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.user.MapUserCredentialEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserCredentialEntity> delegateProvider;
    public MapUserCredentialEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserCredentialEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserCredentialEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserCredentialEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserCredentialEntityFields.ID, id).setId(id);
    }
    @Override public String getType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserCredentialEntityFields.TYPE).getType();
    }
    @Override public void setType(String type) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserCredentialEntityFields.TYPE, type).setType(type);
    }
    @Override public String getUserLabel() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserCredentialEntityFields.USER_LABEL).getUserLabel();
    }
    @Override public void setUserLabel(String userLabel) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserCredentialEntityFields.USER_LABEL, userLabel).setUserLabel(userLabel);
    }
    @Override public Long getCreatedDate() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserCredentialEntityFields.CREATED_DATE).getCreatedDate();
    }
    @Override public void setCreatedDate(Long createdDate) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserCredentialEntityFields.CREATED_DATE, createdDate).setCreatedDate(createdDate);
    }
    @Override public String getSecretData() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserCredentialEntityFields.SECRET_DATA).getSecretData();
    }
    @Override public void setSecretData(String secretData) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserCredentialEntityFields.SECRET_DATA, secretData).setSecretData(secretData);
    }
    @Override public String getCredentialData() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserCredentialEntityFields.CREDENTIAL_DATA).getCredentialData();
    }
    @Override public void setCredentialData(String credentialData) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserCredentialEntityFields.CREDENTIAL_DATA, credentialData).setCredentialData(credentialData);
    }
}
